| Package: |
| SeqGSEA |
| Type: |
| Package |
| License: |
| GPL (>= 3) |
A User's Guide is available as well as the usual help page documentation for each of the individual functions.
The most useful functions are listed below:
* ReadCountSet class
* SeqGeneSet class
* Load data
* DE analysis
* DS analysis
* GSEA main
GSEnrichAnalyze
calES
calES.perm
genePermuteScore
geneScore
rankCombine
normES
normFactor
scoreNormalization
signifES
* Result tables
* Result displays
* Miscellaneous